Method: Diffable::ClassMethods#unique_within_group
- Defined in:
- lib/diffable.rb
#unique_within_group ⇒ Object (readonly)
String value corresponding to the field that uniquely identifies a child record from among its siblings (should not be id unless id is being generated)
247 248 249 |
# File 'lib/diffable.rb', line 247 def unique_within_group @unique_within_group end |